Module errors

Module errors 

Structs

Error
A single validation error associated with a model attribute.
Errors
Ordered collection of validation errors for a model instance.

Enums

ErrorType
Machine-readable validation error kinds.