pub enum ErrorType {
Show 20 variants
Blank,
Invalid,
TooShort,
TooLong,
WrongLength,
NotANumber,
NotAnInteger,
GreaterThan,
LessThan,
EqualTo,
OtherThan,
GreaterThanOrEqualTo,
LessThanOrEqualTo,
Taken,
Accepted,
Confirmation,
Empty,
Exclusion,
Inclusion,
Custom(String),
}Expand description
Machine-readable validation error kinds.
Variants
Blank
The attribute must be present but is blank.
Invalid
The attribute value is invalid.
TooShort
The attribute is shorter than the minimum length.
TooLong
The attribute is longer than the maximum length.
WrongLength
The attribute length does not match the required value.
NotANumber
The attribute is not numeric.
NotAnInteger
The attribute is numeric but not an integer.
GreaterThan
The attribute must be greater than another value.
LessThan
The attribute must be less than another value.
EqualTo
The attribute must equal another value.
OtherThan
The attribute must differ from another value.
GreaterThanOrEqualTo
The attribute must be greater than or equal to another value.
LessThanOrEqualTo
The attribute must be less than or equal to another value.
Taken
The attribute must be unique.
Accepted
The attribute must be accepted.
Confirmation
The attribute confirmation does not match.
Empty
The attribute must not be empty.
Exclusion
The attribute is excluded from an allowed set.
Inclusion
The attribute is not included in an allowed set.
Custom(String)
A custom application-defined error kind.