pub struct Error {
pub attribute: String,
pub error_type: ErrorType,
pub message: String,
pub details: HashMap<String, Value>,
}Expand description
A single validation error associated with a model attribute.
Fields
attribute: StringName of the attribute that produced the error.
error_type: ErrorTypeMachine-readable error category.
message: StringHuman-readable error message.
details: HashMap<String, Value>Extra structured metadata for the error.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn new(attribute: impl Into<String>, message: impl Into<String>) -> Self
pub fn new(attribute: impl Into<String>, message: impl Into<String>) -> Self
Builds an invalid error with no extra details.
Sourcepub fn new_with_type(
attribute: impl Into<String>,
error_type: ErrorType,
message: impl Into<String>,
) -> Self
pub fn new_with_type( attribute: impl Into<String>, error_type: ErrorType, message: impl Into<String>, ) -> Self
Builds an error with an explicit type and no extra details.
Sourcepub fn new_with_default_details(
attribute: impl Into<String>,
message: impl Into<String>,
details: HashMap<String, Value>,
) -> Self
pub fn new_with_default_details( attribute: impl Into<String>, message: impl Into<String>, details: HashMap<String, Value>, ) -> Self
Builds an invalid error with structured details.
Sourcepub fn new_with_details(
attribute: impl Into<String>,
error_type: ErrorType,
message: impl Into<String>,
details: HashMap<String, Value>,
) -> Self
pub fn new_with_details( attribute: impl Into<String>, error_type: ErrorType, message: impl Into<String>, details: HashMap<String, Value>, ) -> Self
Builds an error with an explicit type and structured details.
pub fn full_message(&self) -> String