ModelName

Struct ModelName 

pub struct ModelName {
    pub name: String,
    pub singular: String,
    pub plural: String,
    pub element: String,
    pub collection: String,
    pub human: String,
    pub param_key: String,
    pub route_key: String,
    pub singular_route_key: String,
    pub i18n_key: String,
}
Cached naming metadata derived from a model type name.

Fields

name: String

Canonical type name.

singular: String

Singular underscored key.

plural: String

Plural route key.

element: String

Underscored element name.

collection: String

Collection path used by partial lookup.

human: String

Human-friendly display name.

param_key: String

URL parameter key.

route_key: String

Route collection key.

singular_route_key: String

Singular route key.

i18n_key: String

I18n lookup key.

Implementations

Source

impl ModelName

pub fn new(name: &str) -> Self

Builds naming metadata from a Rust type name such as User or BlogPost.