pub struct SerializationOptions {
pub only: Option<Vec<String>>,
pub except: Option<Vec<String>>,
pub methods: Option<Vec<String>>,
pub include: Option<Vec<SerializationInclude>>,
pub root: Option<String>,
}Expand description
Options controlling model serialization.
Fields
only: Option<Vec<String>>Only include these attributes.
except: Option<Vec<String>>Exclude these attributes.
methods: Option<Vec<String>>Include computed values by name when they can be read dynamically.
include: Option<Vec<SerializationInclude>>Include serialized associations in the requested order.
root: Option<String>Wrap the serialized payload under the given root key.
Implementations
Sourceimpl SerializationOptions
impl SerializationOptions
Sourcepub fn only(self, attrs: Vec<String>) -> Self
pub fn only(self, attrs: Vec<String>) -> Self
Restricts serialization to the provided attributes.
Sourcepub fn methods(self, methods: Vec<String>) -> Self
pub fn methods(self, methods: Vec<String>) -> Self
Appends computed values by name when available.
Sourcepub fn include(self, include: Vec<SerializationInclude>) -> Self
pub fn include(self, include: Vec<SerializationInclude>) -> Self
Appends associations in the requested order.