pub struct FormatValidator { /* private fields */ }Expand description
Validates values against a regular expression.
Implementations
Sourceimpl FormatValidator
impl FormatValidator
Sourcepub fn with_pattern(pattern: &str) -> Self
pub fn with_pattern(pattern: &str) -> Self
Creates a validator that requires values to match pattern.
Sourcepub fn allow_blank(self) -> Self
pub fn allow_blank(self) -> Self
Skips validation when the attribute value is blank.
Sourcepub fn on(self, contexts: Vec<ValidationContext>) -> Self
pub fn on(self, contexts: Vec<ValidationContext>) -> Self
Restricts the validator to the provided contexts.
Sourcepub fn if_cond<F>(self, cond: F) -> Self
pub fn if_cond<F>(self, cond: F) -> Self
Runs the validator only when the predicate returns true.
Sourcepub fn unless_cond<F>(self, cond: F) -> Self
pub fn unless_cond<F>(self, cond: F) -> Self
Skips the validator when the predicate returns true.