Validator

Trait Validator 

pub trait Validator: Send + Sync {
    // Required methods
    fn validate(
        &self,
        attribute: &str,
        value: Option<&Value>,
        errors: &mut Errors,
    );
    fn name(&self) -> &str;
    fn options(&self) -> &ValidatorOptions;

    // Provided method
    fn validate_with_attrs(
        &self,
        attribute: &str,
        value: Option<&Value>,
        _attrs: &dyn Fn(&str) -> Option<Value>,
        errors: &mut Errors,
    ) { ... }
}
A validation rule that can check a value and report errors.

Required Methods

fn validate(&self, attribute: &str, value: Option<&Value>, errors: &mut Errors)

Validates a single attribute value, adding any produced errors.

fn name(&self) -> &str

Returns the validator’s display name.

fn options(&self) -> &ValidatorOptions

Returns the common runtime options for this validator.

Provided Methods

fn validate_with_attrs( &self, attribute: &str, value: Option<&Value>, _attrs: &dyn Fn(&str) -> Option<Value>, errors: &mut Errors, )

Validates a single attribute with access to sibling attributes when needed.

Implementors