pub struct ValidationSet { /* private fields */ }Expand description
Ordered collection of validation rules for a model type.
Implementations
Sourceimpl ValidationSet
impl ValidationSet
Sourcepub fn add(
&mut self,
attribute: impl Into<String>,
validator: impl Validator + 'static,
)
pub fn add( &mut self, attribute: impl Into<String>, validator: impl Validator + 'static, )
Adds a validator for the given attribute.
Sourcepub fn validators_on(&self, attribute: &str) -> Vec<&dyn Validator>
pub fn validators_on(&self, attribute: &str) -> Vec<&dyn Validator>
Returns validators registered for the given attribute in registration order.